@@ -18,6 +18,7 @@ from typing import Optional
 
 from modelstore.models.managers import iter_libraries
 from modelstore.storage.aws import BOTO_EXISTS, AWSStorage
+from modelstore.storage.azure import AZURE_EXISTS, AzureBlobStorage
 from modelstore.storage.gcloud import GCLOUD_EXISTS, GoogleCloudStorage
 from modelstore.storage.hosted import HostedStorage
 from modelstore.storage.local import FileSystemStorage
@@ -49,6 +50,16 @@ class ModelStore:
             storage=AWSStorage(bucket_name=bucket_name, region=region)
         )
 
+    @classmethod
+    def from_azure(cls, container_name: str) -> "ModelStore":
+        """Creates a ModelStore instance that stores models to an
+        Azure blob container. This assumes that the container already exists."""
+        if not AZURE_EXISTS:
+            raise ModuleNotFoundError("azure-storage-blob is not installed!")
+        return ModelStore(
+            storage=AzureBlobStorage(container_name=container_name),
+        )
+
     @classmethod
     def from_gcloud(cls, project_name: str, bucket_name: str) -> "ModelStore":
         """Creates a ModelStore instance that stores models to a
@@ -83,18 +94,31 @@ class ModelStore:
                 f"Failed to set up the {type(self.storage).__name__} storage."
             )
         # Supported machine learning model libraries
+        managers = []
         for library, manager in iter_libraries(self.storage):
             object.__setattr__(self, library, manager)
+            managers.append(manager)
+        object.__setattr__(self, "_managers", managers)
 
     def list_domains(self) -> list:
         """Returns a list of dicts, containing info about all
         of the domains"""
         return self.storage.list_domains()
 
-    def list_versions(self, domain: str) -> list:
-        """Returns a list of dicts, containing info about all
-        of the models that have been uploaded to a domain"""
-        return self.storage.list_versions(domain)
+    def list_versions(
+        self, domain: str, state_name: Optional[str] = None
+    ) -> list:
+        """Returns a list of dicts, containing info about the
+        models that have been uploaded to a domain; if state_name
+        is given results are filtered to models set to that state"""
+        return self.storage.list_versions(domain, state_name)
+
+    def upload(self, domain: str, **kwargs) -> dict:
+        # pylint: disable=no-member
+        for manager in self._managers:
+            if manager.matches_with(**kwargs):
+                return manager.upload(domain, **kwargs)
+        raise ValueError("unable to upload: %s", **kwargs)
 
     def download(
         self, local_path: str, domain: str, model_id: str = None
@@ -105,3 +129,13 @@ class ModelStore:
             tar.extractall(local_path)
         os.remove(archive_path)
         return local_path
+
+    def create_model_state(self, state_name: str):
+        """ Creates a state label models (e.g., shadow/prod/archived) """
+        return self.storage.create_model_state(state_name)
+
+    def set_model_state(self, domain: str, model_id: str, state_name: str):
+        """Sets the model_id model to a specific state.
+        That state must already exist (ref: `create_model_state()`)
+        """
+        return self.storage.set_model_state(domain, model_id, state_name)
