@@ -18,10 +18,11 @@ import numpy as np
 import pandas as pd
 import pytest
 from modelstore.models.sklearn import SKLearnManager, _feature_importances
-from sklearn.ensemble import GradientBoostingRegressor
+from sklearn.ensemble import RandomForestRegressor
 from sklearn.linear_model import LogisticRegression
 from sklearn.pipeline import Pipeline
 from sklearn.preprocessing import StandardScaler
+from tests.models.test_xgboost import xgb_model
 from tests.models.utils import classification_data
 
 # pylint: disable=protected-access
@@ -31,13 +32,12 @@ from tests.models.utils import classification_data
 @pytest.fixture
 def sklearn_tree():
     params = {
-        "n_estimators": 500,
+        "n_estimators": 5,
         "max_depth": 4,
         "min_samples_split": 5,
-        "learning_rate": 0.01,
-        "loss": "ls",
+        "n_jobs": 1,
     }
-    return GradientBoostingRegressor(**params)
+    return RandomForestRegressor(**params)
 
 
 @pytest.fixture
@@ -64,8 +64,8 @@ def sklearn_manager():
     "model_type,expected",
     [
         (
-            GradientBoostingRegressor,
-            {"library": "sklearn", "type": "GradientBoostingRegressor"},
+            RandomForestRegressor,
+            {"library": "sklearn", "type": "RandomForestRegressor"},
         ),
         (
             LogisticRegression,
@@ -73,7 +73,7 @@ def sklearn_manager():
         ),
         (
             partial(
-                Pipeline, steps=[("regressor", GradientBoostingRegressor())]
+                Pipeline, steps=[("regressor", RandomForestRegressor(n_jobs=1))]
             ),
             {"library": "sklearn", "type": "Pipeline"},
         ),
@@ -95,6 +95,13 @@ def test_required_kwargs(sklearn_manager):
     assert sklearn_manager._required_kwargs() == ["model"]
 
 
+def test_matches_with(sklearn_manager, sklearn_tree, xgb_model):
+    assert sklearn_manager.matches_with(model=sklearn_tree)
+    assert not sklearn_manager.matches_with(model="a-string-value")
+    assert not sklearn_manager.matches_with(classifier=sklearn_tree)
+    assert not sklearn_manager.matches_with(model=xgb_model)
+
+
 def test_get_functions(sklearn_manager, sklearn_tree):
     assert len(sklearn_manager._get_functions(model=sklearn_tree)) == 1
     with pytest.raises(TypeError):
@@ -104,9 +111,11 @@ def test_get_functions(sklearn_manager, sklearn_tree):
 @pytest.mark.parametrize(
     "model_type",
     [
-        GradientBoostingRegressor,
+        RandomForestRegressor,
         LogisticRegression,
-        partial(Pipeline, steps=[("regressor", GradientBoostingRegressor())]),
+        partial(
+            Pipeline, steps=[("regressor", RandomForestRegressor(n_jobs=1))]
+        ),
     ],
 )
 def test_get_params(sklearn_manager, model_type):
