@@ -18,15 +18,19 @@ import pytest
 from sklearn.datasets import make_classification
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def classification_data():
     X_train, y_train = make_classification(
-        n_features=10, n_redundant=0, n_informative=3, n_clusters_per_class=1
+        n_samples=50,
+        n_features=5,
+        n_redundant=0,
+        n_informative=3,
+        n_clusters_per_class=1,
     )
     return X_train, y_train
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def classification_df(classification_data):
     X_train, y_train = classification_data
     df = pd.DataFrame(
@@ -37,6 +41,6 @@ def classification_df(classification_data):
     return df
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def classification_row(classification_df):
     return classification_df.iloc[randint(0, classification_df.shape[0] - 1)]
